@@ -256,7 +256,7 @@ class FridaApplication(FridaScriptHandler):
             self,
             device: Union[frida.core.Device, "FridaServer"],
             user_parameters: Dict[str, any] = None,
-            user_scripts: Collection[Union[str, FridaUserScript]] = None,
+            user_scripts: Collection[FridaUserScript] = None,
             enable_spawn_gating: bool = False,
             enable_child_gating: bool = False,
             eternalize: str = False,
@@ -288,7 +288,7 @@ class FridaApplication(FridaScriptHandler):
         self._internal_debug_script = FridaScriptFile(resource.get_asset_path("frida.js"))
 
         self._user_parameters = user_parameters or {}
-        self._user_scripts = [FridaScriptFile(o) if isinstance(o, str) else o for o in (user_scripts or tuple())]
+        self._user_scripts = user_scripts or tuple()
 
         self._enable_spawn_gating = enable_spawn_gating
         self._enable_child_gating = enable_child_gating
