@@ -10,22 +10,26 @@ from typing import Optional
 
 from linktools import utils, tools
 
-_shell_path = None
-if tools.system in ["darwin", "linux"]:
-    _shell_path = pwd.getpwnam(getpass.getuser()).pw_shell
-    if "SHELL" in os.environ:
-        _shell_path = os.environ["SHELL"]
-elif tools.system in ["windows"]:
-    _shell_path = shutil.which("powershell") or shutil.which("cmd")
-    if "ComSpec" in os.environ:
-        _shell_path = os.environ["ComSpec"]
-
 
 class Script(utils.ConsoleScript):
 
+    def __init__(self):
+        self._shell_path = None
+        if tools.system in ["darwin", "linux"]:
+            try:
+                self._shell_path = pwd.getpwnam(getpass.getuser()).pw_shell
+            except:
+                self._shell_path = shutil.which("bash") or shutil.which("sh")
+            if "SHELL" in os.environ:
+                self._shell_path = os.environ["SHELL"]
+        elif tools.system in ["windows"]:
+            self._shell_path = shutil.which("powershell") or shutil.which("cmd")
+            if "ComSpec" in os.environ:
+                self._shell_path = os.environ["ComSpec"]
+
     @property
     def _description(self) -> str:
-        return "shell wrapper"
+        return f"shell wrapper"
 
     def _add_arguments(self, parser: ArgumentParser) -> None:
         parser.add_argument("-c", "--command", action="store", default=None, help="shell args")
@@ -36,10 +40,10 @@ class Script(utils.ConsoleScript):
             process = utils.Popen(args.command, shell=True)
             return process.call()
 
-        if not os.path.exists(_shell_path):
+        if not os.path.exists(self._shell_path):
             raise NotImplementedError(f"unsupported system {tools.system}")
 
-        process = utils.Popen(_shell_path)
+        process = utils.Popen(self._shell_path)
         return process.call()
 
 
